<?php
/*
 #########################################################################
 #                       xt:Commerce  4.1 Shopsoftware
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 #
 # Copyright 2007-2014 xt:Commerce International Ltd. All Rights Reserved.
 # This file may not be redistributed in whole or significant part.
 # Content of this file is Protected By International Copyright Laws.
 #
 # ~~~~~~ xt:Commerce  4.1 Shopsoftware IS NOT FREE SOFTWARE ~~~~~~~
 #
 # http://www.xt-commerce.com
 #
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 #
 # @version $Id$
 # @copyright xt:Commerce International Ltd., www.xt-commerce.com
 #
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 #
 # xt:Commerce International Ltd., Kafkasou 9, Aglantzia, CY-2112 Nicosia
 #
 # office@xt-commerce.com
 #
 #########################################################################
 */

defined('_VALID_CALL') or die('Direct Access is not allowed.');

/**
 * Class csv_field
 * Used to represent export/import field
 *
 */
class csv_field {
	/**
	 * Instore mapped field
	 * @var string|null
	 */
	protected $_store_field = null;
	
	/**
	 * CSV mapped field
	 * @var string|null
	 */
	protected $_csv_field = null;
	
	/**
	 * Field settings
	 * @var array
	 */
	protected $_settings = array();
	
	/**
	 * class constructor
	 * @param array $fieldData
	 */
	function csv_field($fieldData) {
		// Set default values
		$this->setStoreField($fieldData['store_field']);
		$this->setCsvField($fieldData['csv_field']);
		
		// Always add filter code setting
		$this->_settings[xt_pro_import_fields_settings::SETTING_FILTER_CODE] = $fieldData[xt_pro_import_fields_settings::SETTING_FILTER_CODE];
		// Check if this field name has any settings if it has set them from the record
		if (isset(xt_pro_import_fields_settings::$_fieldsHavingSettings[$fieldData['store_field']])) {
			foreach (xt_pro_import_fields_settings::$_fieldsHavingSettings[$fieldData['store_field']] as $settingColumn) {
				$this->_settings[$settingColumn] = $fieldData[$settingColumn];
			}
		}
	}
	
	/**
	 * Getter for store field
	 * @return Ambigous <string, NULL>
	 */
	public function getStoreField() {
		return $this->_store_field;
	}
	
	/**
	 * Getter for CSV field
	 * @return Ambigous <string, NULL>
	 */
	public function getCsvField() {
		return $this->_csv_field;
	}
	
	/**
	 * Setter for store field
	 * @param string $fieldName
	 */
	public function setStoreField($fieldName) {
		$this->_store_field = $fieldName;
	}
	
	/**
	 * Setter for CSV field
	 * @param string $fieldName
	 */
	public function setCsvField($fieldName) {
		$this->_csv_field = $fieldName;
	}
	
	/**
	 * Get value for export depending on setting set for this column
	 * @param string $fieldValue
	 * @param array $recordData
	 * @return Ambigous <string, string, mixed, unknown, number>
	 */
	public function getValueForExport($fieldValue, $recordData) {
		return xt_pro_import_fields_settings::getValueForColumn($this->getStoreField(), $fieldValue, $this->_settings, $recordData);
	}
	
	/**
	 * Get value for import depending on settings
	 * @param string $value
	 * @param string $line_data
	 * @return Ambigous <mixed, unknown, number>
	 */
	public function getValueForImport($value, $line_data) {
		global $price;
		
		if ($this->getStoreField() == 'products_price') {
			$value = str_replace(',', '.', $value);
			$value = preg_replace('#([A-Za-z\s]+)#', '', $value);
			
			if($this->_settings[xt_pro_import_fields_settings::SETTINGS_COLUMN_PRICE_INCL_TAX] == 'true')
				$value = $price->_BuildPrice($value, $line_data['products_tax_class_id'], 'save');
		} else if ($this->getStoreField() == 'products_image') {
			// Check if image comes from external website, if so download it
			if ((strpos($value, 'http://') !== false) || (strpos($value, 'https://') !== false)) {
				$ds = DIRECTORY_SEPARATOR;
				$value = csv_pro_api::downloadImage($value,  _SRV_WEBROOT . 'media' . $ds . 'images' . $ds . 'org' . $ds);
			}
		} else if ($this->getStoreField() == 'manufacturers_id') {
			// Manufacturer Id can be eigher a number which represents id of the manufacturer
			// in the store or can be manufacturer name. If it is name, check if manufacturer already exists,
			// and if not create one and assign that id to the value.
			if (!ctype_digit($value)) {
				$value = csv_pro_api::getManufacturerIdByName($value);
			}
		}
		
		if (isset($this->_settings[xt_pro_import_fields_settings::SETTING_FILTER_CODE]) && !empty($this->_settings[xt_pro_import_fields_settings::SETTING_FILTER_CODE])) {
			@eval($this->_settings[xt_pro_import_fields_settings::SETTING_FILTER_CODE]);
		}
		return $value;
	}
}